/**
 * This software is the confidential and proprietary information of
 * ATP and may not be used, reproduced, modified, distributed,
 * publicly displayed or otherwise disclosed without the express written
 * consent of ATP. 
 */

/*jslint browser: true*/
/*global sample_data,$, jQuery,constants,applicationDataObj,loggerObj,endLoading,logout,apiservicecalls,AccountDataClass*/

var sample_data;
var accountContactClass = function () {
	/**
	 * Get Contact Request parameters
	 */
	this.getContactRequestParameters = function (sessionData) {
		try {
			var data = {}, userSession = {}, inputData;
			if (sessionData) {
				data.Userid = sessionData.userId;
				data.ServiceProvider = "MyProfileServiceProvider";
				data.ServiceMethod = "GetContact";
				data.Language = constants.englishLanguage;
				data.parametersArray =  ["FC47DAF7-99D8-4C86-9FB6-35068DA99738"];
				userSession.PlayerId = sessionData.playerId;
				userSession.UserId = sessionData.userId;
				userSession.FirstName = sessionData.firstName;
				userSession.LastName = sessionData.lastName;
				userSession.Roles = sessionData.roles;
				userSession.UserName = applicationDataObj.getUsername();
				userSession.EmailId = sessionData.emailId;
				userSession.Address1 = sessionData.address1;
				userSession.City = sessionData.city;
				userSession.Country = sessionData.country;
				userSession.TOKEN  = applicationDataObj.getToken();
				data.SessionData = userSession;
			}
			inputData = JSON.stringify(data);
			return inputData;
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getContactRequestParameters " + err);
		}
	};
	/**
	 * Get Key name from value
	 */
	this.getKeyNameFromValue = function (countryObj, country) {
		try {
			var val = "";
			$.each(countryObj, function (key, value) {
				if (value === country) {
					val =  key;
				}
			});
			return val;
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getKeyNameFromValue " + err);
		}
	};
	/**
	 * Save Success
	 */
	this.onSaveContactSuccess = function (data) {
		try {
			$("#contact-save-msg").removeClass("hide");
			$("#contact-save-msg").addClass("show");
			endLoading();
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : onSaveContactSuccess " + err);
		}
	};
	/**
	 * Save Error
	 */
	this.onsaveContactError = function (jqXHR, exception) {
		try {
			endLoading();
			loggerObj.logToServer(constants.logSeverityError, "Error : onsaveContactError " + jqXHR + exception);
			if (jqXHR.status && jqXHR.status === 401 &&
					jqXHR.statusText === "Unauthorized") {
				logout();
			}
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : onsaveContactError " + err);
		}
	};
	/**
	 * Creating request for contact save
	 */
	this.createRequestForContactSave = function () {
		try {
			var data = {},
			    sessionData = applicationDataObj.getSessionResponse(),
                userSession = {},
                parametersArray = [],
                inputData,
			    contactObject = {};
			data.Userid = sessionData.userId;
			data.ServiceProvider = "MyProfileServiceProvider";
			data.ServiceMethod = "SaveContact";
			data.Language = constants.englishLanguage;
			userSession.PlayerId = sessionData.playerId;
			userSession.UserId = sessionData.userId;
			userSession.FirstName = sessionData.firstName;
			userSession.LastName = sessionData.lastName;
			userSession.Roles = sessionData.roles;
			userSession.UserName = applicationDataObj.getUsername();
			userSession.EmailId = sessionData.emailId;
			userSession.Address1 = sessionData.address1;
			userSession.City = sessionData.city;
			userSession.Country = sessionData.country;
			userSession.TOKEN  = applicationDataObj.getToken();
			data.SessionData = userSession;
			contactObject.MailingStreet = $("#mailadrs-street1").val();
			contactObject.MailingStreet2 = $("#mailadrs-street2").val();
			contactObject.MailingCity = $("#mycntct-city").val();
			contactObject.MailingState = $("#state-province").val();
			contactObject.MailingZip = $("#zip").val();
			contactObject.MailingCountry = $("#mycntct-cntry").val();
			contactObject.PhoneNumber = $("#home-phn").val();
			contactObject.PhoneNumberWork = $("#work-phn").val();
			contactObject.PhoneNumberFax = $("#fax-phn").val();
			contactObject.PhoneNumberMobile = $("#mob-phn").val();
			contactObject.EmailAddressPrimary = $("#email-prmryemail").val();
			contactObject.EmailAddressSecondary = $("#pscndry-email").val();
			contactObject.EmailAddressAgent = $("#agent-email").val();
			parametersArray.push(contactObject);
			parametersArray.push("FC47DAF7-99D8-4C86-9FB6-35068DA99738");
			data.parametersArray = parametersArray;
			inputData = JSON.stringify(data);
			return inputData;
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : createRequestForContactSave " + err);
		}
	};
	/**
	 * Get data for contact
	 */
	this.getDataForContact = function () {
		try {
			var apiservicecallsObj = new apiservicecalls(),
			    url =  constants.ajaxUrl,
			    sessionData = applicationDataObj.getSessionResponse(),
			    inputData = this.getContactRequestParameters(sessionData);
			apiservicecallsObj.postData(url, inputData, this.OnContactSuccess, this.OnContactError);
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getDataForContact " + err);
		}
	};
	/**
	 * Contact Success
	 */
	this.OnContactSuccess = function (data) {
		try {
			if (data) {
				sample_data = data;
				var accountDataClassObj = new AccountDataClass();
				accountDataClassObj.populateFields(data);
				accountDataClassObj.bindContactDetails(data);
			}
			setTimeout(function () {
				endLoading();
			}, 200);
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : OnContactSuccess " + err);
		}
	};
	/**
	 * Contact Error
	 */
	this.OnContactError = function (jqXHR, exception) {
		try {
			loggerObj.logToServer(constants.logSeverityError, "Error : OnContactError " + jqXHR + exception);
			endLoading();
			if (jqXHR.status && jqXHR.status === 401 &&
					jqXHR.statusText === "Unauthorized") {
				logout();
			}
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : OnContactError " + err);
		}
	};
	/**
	 * Remove error messages
	 */
	this.removeErrorMessages = function () {
		try {
			$(".valdterror").addClass("hide");
            $(".PhoneValidation").addClass("hide");
			$(".valdterror").removeClass("show");
			$("input").removeClass("error-border");
			if ($("select").parent()) {
				$("select").parent().removeClass("error-border");
			}
			$("#contact-save-msg").removeClass("show");
			$("#contact-save-msg").addClass("hide");
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : removeErrorMessages " + err);
		}
	};
	/**
	 * Validate Errors
	 */
	this.validateErrors = function () {
		try {
			var noError = true;
			$("#contact .valdtnerror-message").each(function (i, obj) {
				if ($(obj).hasClass("show")) {
					noError = false;
				}
			});
			return noError;
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : validateErrors " + err);
		}
	};
	/**
	 * Common function for add/remove Class
	 */
	this.addRemoveClass = function (id, addClass, removeClass) {
		try {
			$(id).addClass(addClass);
			$(id).removeClass(removeClass);
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : addRemoveClass " + err);
		}
	};
};

/**
 * Validate fields
 */
var vaidateFields = function (elementId, borderId, errorClass, invalidFormatClass) {
	try {
		var accountContactClassObj = new accountContactClass(),
            toCheckValue;
        if (elementId === "#home-phn") {
            return true;
        } else {
            toCheckValue = $(elementId).val();
            $(borderId).addClass("error-border");
            if (!toCheckValue) {
                $(borderId).addClass("error-border");
                accountContactClassObj.addRemoveClass(errorClass, "show", "hide");
                accountContactClassObj.addRemoveClass(invalidFormatClass, "hide", "show");
                if (elementId === "#home-phn") {
                    $("#phn-code").addClass("error-border");
                }
                if ($('#mailadrs-street1').val() === "") {
                    $('#mailadrs-street1').focus();
                }
                if ($('#mycntct-city').val() === "") {
                    $('#mycntct-city').focus();
                }
                if ($('#mycntct-cntry').val() === "") {
                    $('#mycntct-cntry').focus();
                }
                if ($('#email-prmryemail').val() === "") {
                    $('#email-prmryemail').focus();
                }
                
                return false;
            } else {
                accountContactClassObj.addRemoveClass(errorClass, "hide", "show");
                accountContactClassObj.addRemoveClass(invalidFormatClass, "hide", "show");
                $(borderId).removeClass("error-border");
                $("#phn-code").removeClass("error-border");
                return true;
            }
        }
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : vaidateFields " + err);
	}
};

/**
 * Validate Phone number
 */
var validatePhoneNumber = function (elementId, borderId, errorClass, code) {
	try {
		var isValidPhoneNumber = true,
            accountContactClassObj = new accountContactClass(),
            toCheckValue = $(elementId).val(),
            regexPhoneCheck;
		if (toCheckValue) {
			regexPhoneCheck = /[0-9]{1,30}$/;
			if (regexPhoneCheck.test(toCheckValue)) {
				accountContactClassObj.addRemoveClass(errorClass, "hide", "show");
				$(borderId).removeClass("error-border");
				isValidPhoneNumber =  true;
			} else {
				$(borderId).addClass("error-border");
				accountContactClassObj.addRemoveClass(errorClass, "show", "hide");
				isValidPhoneNumber = false;
			}
			if (isValidPhoneNumber) {
				if (isNaN(toCheckValue)) {
					isValidPhoneNumber = false;
					$(borderId).addClass("error-border");
					accountContactClassObj.addRemoveClass(errorClass, "show", "hide");
				}
			} else {
				$(borderId).addClass("error-border");
				accountContactClassObj.addRemoveClass(errorClass, "show", "hide");
			}
			return isValidPhoneNumber;
		}
		
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : validatePhoneNumber " + err);
	}
};
/**
 * Validate Email format
 */
var validateEmailFormat = function (elementId, borderId, errorClass) {
	try {
		var accountContactClassObj = new accountContactClass(),
            toCheckValue = $(elementId).val(),
            regexEmailCheck;
		if (toCheckValue) {
			//var regexEmailCheck = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
			regexEmailCheck = /^([a-zA-Z0-9_.+-])+\@(([a-zA-Z0-9-])+\.)+([a-zA-Z0-9]{2,4})+$/;
			if (regexEmailCheck.test(toCheckValue)) {
				accountContactClassObj.addRemoveClass(errorClass, "hide", "show");
				$(borderId).removeClass("error-border");
				return true;
			} else {
				$(borderId).addClass("error-border");
				accountContactClassObj.addRemoveClass(errorClass, "show", "hide");
				return false;
			}
		}
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : validateEmailFormat " + err);
	}
};
/**
 * To Clear Fields
 */
var clearFields = function (elementId, borderId, errorClass, phoneCode) {
	try {
		var accountContactClassObj = new accountContactClass();
		accountContactClassObj.addRemoveClass(errorClass, "hide", "show");
		$(borderId).removeClass("error-border");
		$(phoneCode).removeClass("error-border");
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : clearFields " + err);
	}
};
/**
 * Save button click
 */
this.saveContactDetails = function () {
	try {
        $('.PhoneValidation').css("display", "none");
		var accountContactClassObj = new accountContactClass(),
            apiservicecallsObj = new apiservicecalls(),
            url =  constants.ajaxUrl,
            homePhoneval = $("#home-phn").val(),
            workPhoneval = $("#work-phn").val(),
            mobPhoneval = $("#mob-phn").val(),
            faxPhoneval = $("#fax-phn").val(),
            validateStreet = vaidateFields("#mailadrs-street1", ".mycntct-street1 .textbox-input1", '.streetvalidation'),
            validateEmail = vaidateFields("#email-prmryemail", ".mycntctemail-primaryemail .textbox-input1", '.email-vldtn'),
            validateCity = vaidateFields("#mycntct-city", ".mycntct-city .textbox-input1", '.cityvalidation'),
            validatePhone =  vaidateFields("#home-phn", ".mycntct-homephn .textbox-input3", '.phnvalidation1'),
            validateCountry = vaidateFields("#mycntct-cntry", ".mycntct-cntry", '.cntryvalidation'),
            checkIfErrorExists = accountContactClassObj.validateErrors(),
            inputData;
		if (validateStreet && validateEmail && validateCity && validatePhone && validateCountry && checkIfErrorExists) {
            if (homePhoneval !== "" || workPhoneval !== "" || mobPhoneval !== "" || faxPhoneval !== "") {
                inputData = accountContactClassObj.createRequestForContactSave();
                apiservicecallsObj.postData(url, inputData, accountContactClassObj.onSaveContactSuccess,
                    accountContactClassObj.onsaveContactError);
            } else {
                $('.PhoneValidation').css("display", "inline");
                $('#phn-code').focus();
                endLoading();
            }
        }
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : saveContactDetails " + err);
	}
};
/**
 * Cancel edit made by user
 */
var cancelContactDetails = function () {
	try {
		var accountContactClassObj = new accountContactClass(),
            accountDataClassObj = new AccountDataClass();
		accountContactClassObj.removeErrorMessages();
		accountDataClassObj.bindContactDetails(sample_data);
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : cancelContactDetails " + err);
	}
};
/**
 * Contact ATP button click
 */
var contactplayerRelations = function () {
	try {
		window.location.href = '#/Contact-Player-Relations';
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : contactplayerRelations " + err);
	}
};

