/**
 * This software is the confidential and proprietary information of
 * ATP and may not be used, reproduced, modified, distributed,
 * publicly displayed or otherwise disclosed without the express written
 * consent of ATP. 
 */
/*jslint browser: true*/
/*global $, jQuery,loggerObj,constants,Apiservicecalls,applicationDataObj,endLoading,logout,startLoading,headerMain,subHeaderHide,isApp,navigationRulesArrowMenu,navigationRulesAlumniArrowMenu*/

/* Anti corruption class */
var AntiCorruptClass = function () {
    /** get Anti corruption data **/
    this.getAntiCorruptData = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                inputData = this.getCorruptionRequestParameters();
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnCorruptionSuccess, this.OnCorruptionError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getAntiCorruptData " + err);
        }
    };
    
    /** Creating request Parameters **/
    this.getCorruptionRequestParameters = function () {
        try {
            var sessionData = applicationDataObj.getSessionResponse(),
                data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "BenefitsServiceProvider";
            data.ServiceMethod = "GetATPAdvantage";
            data.Language = constants.englishLanguage;
            data.parametersArray = ["A04DB66C-9799-41A9-88BE-E3C26B4AABB1"];
            userSession.PlayerId = sessionData.playerId;
            userSession.UserId = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.Country = sessionData.country;
            userSession.TOKEN  = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getCorruptionRequestParameters " + err);
        }
    };
    
    /** binding Corrupt body data **/
    this.bindCorruptionResponse = function (data) {
        try {
            
            $("#rules-anti-corruption").append(data.Content);
            if (data.Query !== null) {
                var scriptQuery = '<script language="JavaScript">';
                scriptQuery = scriptQuery + data.Query;
                scriptQuery = scriptQuery + '</script>';
                $("#rules-anti-corruption").append(scriptQuery);
            }

        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : bindCorruptionResponse " + err);
        }
    };
    
     /*Ajax - Success Call back*/
    this.OnCorruptionSuccess = function (data) {
        try {
            var corruptClassObj = new AntiCorruptClass();
            corruptClassObj.bindCorruptionResponse(data);
            endLoading();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnCorruptionSuccess " + err);
        }
    };
    
    /*Ajax - Error Call back*/
    this.OnCorruptionError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnCorruptionError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnCorruptionError " + err);
        }
    };
};

/* Anti corruption */

var antiCorruption = function () {
    try {
        if (isApp) {
            window.ga.trackView('Rules Anti-Corruption');
        }
        var antiCorruptObj = new AntiCorruptClass();
        startLoading();
        headerMain();
        subHeaderHide();
        antiCorruptObj.getAntiCorruptData();
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "Error : antiCorruption " + err);
    }
};

function subHeaderHide() {
    try {
		var role  = "",
            lowerConvertedRole;
		if (applicationDataObj.getSessionResponse() && applicationDataObj.getSessionResponse().roles && applicationDataObj.getSessionResponse().roles.length !== 0) {
		    role = applicationDataObj.getSessionResponse().roles[0];
		    $(".player-status").text(role);
		}
		if (role) {
			lowerConvertedRole = role.toLowerCase();
			if ((lowerConvertedRole.indexOf(("Division I Player").toLowerCase()) !== -1)  || (lowerConvertedRole.indexOf(("Division II Player").toLowerCase()) !== -1) || (lowerConvertedRole.indexOf(("Registered Player").toLowerCase()) !== -1)) {
                $(".alumni").addClass("hide");
                $(".player").removeClass("hide");
                navigationRulesArrowMenu();
			} else {
                $(".alumni").removeClass("hide");
                $(".player").addClass("hide");
                navigationRulesAlumniArrowMenu();
			}
		}
		
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : subHeaderHide " + err);
	}
}

var navigationRulesArrowMenu = function () {
    var firstContactAct = $("#rightarrow").parent().children().children().children(".playeritem").first().hasClass("active"),
        lastContactAct = $("#rightarrow").parent().children().children().children(".playeritem").last().hasClass("active");
    if (firstContactAct !== true && lastContactAct !== true) {
        $("#leftarrow").show();
        $("#rightarrow").show();
    } else if (firstContactAct === true) {
        $("#leftarrow").hide();
        $("#rightarrow").show();
    } else if (lastContactAct === true) {
        $("#leftarrow").show();
        $("#rightarrow").hide();
    }
    $("#rightarrow").click(function () {
        firstContactAct = $("#rightarrow").parent().children().children().children(".playeritem").first().hasClass("active");
        lastContactAct = $("#rightarrow").parent().children().children().children(".playeritem").last().hasClass("active");
        if (firstContactAct !== true && lastContactAct !== true) {
            $("#leftarrow").show();
            $("#rightarrow").hide();
        } else if (firstContactAct === true) {
            $("#leftarrow").show();
            $("#rightarrow").hide();
        } else if (lastContactAct === true) {
            $("#leftarrow").show();
            $("#rightarrow").hide();
        }
    });

    $("#leftarrow").click(function () {
        firstContactAct = $("#leftarrow").parent().children().children().children(".playeritem").first().hasClass("active");
        lastContactAct = $("#leftarrow").parent().children().children().children(".playeritem").last().hasClass("active");
        if (lastContactAct === true) {
            $("#leftarrow").hide();
            $("#rightarrow").show();
        } else if (firstContactAct !== true && lastContactAct !== true) {
            $("#leftarrow").hide();
            $("#rightarrow").show();
        }
    });
};
