/**
 * This software is the confidential and proprietary information of
 * ATP and may not be used, reproduced, modified, distributed,
 * publicly displayed or otherwise disclosed without the express written
 * consent of ATP. 
 */

/*jslint browser: true*/
/*global $, jQuery,loggerObj,constants,startLoading,moment,applicationDataObj,refreshTokenTimer,onError*/

/***
 * apiservicecalls Class
 */
var apiservicecalls = function () {
	/***
	 * Ajax call for getting/posting datas from/to webservices
	 */
	this.getDataFromService = function (url, inputData, type, OnSuccess, onError) {
		try {
			var headers = {
				"Access-Control-Allow-Origin": "*",
				"Access-Control-Allow-Headers": "Origin, X-Requested-With, Content-Type, Accept"
			};
			$.ajax({
				type: type,
				url: url,
				data: inputData,
				contentType: "application/json",
				processData: false,
				headers : headers,
				success: OnSuccess,
				error: onError,
				async: false
			});
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getDataFromService" + err);
		}
	};
	/***
	 * Ajax functionality for POST Calls
	 */
	this.postData = function (url, inputData, OnSuccess, onError) {
		try {
			if (!constants.liveScoreLoading) {
				startLoading();
			}
            var bearerToken = applicationDataObj.getToken();
			$.ajax({
				type : "POST",
				url : url,
				data : inputData,
				contentType : "application/json",
				processData : false,
				headers : {
					"Content-Type" : "application/json",
					"Authorization" : "Bearer " + bearerToken
				},
				timeout : 60000,
				success : OnSuccess,
				error : onError,
				async : true
			});
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : postData" + err);
		}
	};
	/**
	 * Get headers
	 */
	this.getHeaders = function () {
		try {
			var bearerToken = applicationDataObj.getToken(),
                headers = {
                    "Content-Type": "application/json",
                    "Authorization": "Bearer " + bearerToken
                };
			return headers;
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getHeaders" + err);
		}
	};
	/**
	 * Ajax GET calls
	 */
	this.getData = function (url, OnSuccess, OnError) {
		try {
			var headers = {
				"Content-Type" : "application/json"
			};
			$.ajax({
				type: "GET",
				url: url,
				contentType: "application/json",
				processData: false,
				headers : headers,
				success: OnSuccess,
				error: OnError,
				async: true
			});
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getData" + err);
		}
	};
};


/***
 * apiservicecalls Class
 */
var Apiservicecalls = function () {
	/***
	 * Ajax call for getting/posting datas from/to webservices
	 */
	this.getDataFromService = function (url, inputData, type, OnSuccess, onError) {
		try {
			var headers = {
				"Access-Control-Allow-Origin": "*",
				"Access-Control-Allow-Headers": "Origin, X-Requested-With, Content-Type, Accept"
			};
			$.ajax({
				type: type,
				url: url,
				data: inputData,
				contentType: "application/json",
				processData: false,
				headers : headers,
				success: OnSuccess,
				error: onError,
				async: false
			});
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getDataFromService" + err);
		}
	};
	/***
	 * Ajax functionality for POST Calls
	 */
	this.postData = function (url, inputData, OnSuccess, onError) {
		try {
            var bearerToken = applicationDataObj.getToken();
			if (!constants.liveScoreLoading) {
				startLoading();
			}
			$.ajax({
				type : "POST",
				url : url,
				data : inputData,
				contentType : "application/json",
				processData : false,
				headers : {
					"Content-Type": "application/json",
					"Authorization" : "Bearer " + bearerToken
				},
				timeout : 60000,
				success : OnSuccess,
				error : onError,
				async : true
			});
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : postData" + err);
		}

	};
	/**
	 * Get headers
	 */
	this.getHeaders = function () {
		try {
			var bearerToken = applicationDataObj.getToken(),
                headers = {
					"Content-Type" : "application/json",
					"Authorization" : "Bearer " + bearerToken
                };
			return headers;
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getHeaders" + err);
		}
	};
	/**
	 * Ajax GET calls
	 */
	this.getData = function (url, OnSuccess, OnError) {
		try {
			var headers = {
				"Access-Control-Allow-Origin" : "*",
				"Access-Control-Allow-Headers" : "Origin, X-Requested-With, Content-Type, Accept"
			};
			$.ajax({
				type : "GET",
				url : url,
				contentType : "application/json",
				processData : false,
				headers : headers,
				success : OnSuccess,
				error : onError,
				async : false
			});
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "Error : getHeaders" + err);
		}
	};
};