/**
 * This software is the confidential and proprietary information of
 * ATP and may not be used, reproduced, modified, distributed,
 * publicly displayed or otherwise disclosed without the express written
 * consent of ATP. 
 */

/*jslint browser: true*/
/*global $, jQuery,loggerObj,constants,Apiservicecalls,applicationDataObj,endLoading,logout,isApp,startLoading,headerMain,subHeaderBenefitsHide,navigationArrowMenuAgent,navigationArrowMenu*/

var BenefitsAdvantagesClass = function () {
    /** get atp advantage data **/
    this.getAtpAdvantageData = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                inputData = this.getATPAdvantageParameters();
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.onAtpAdvantageSuccess, this.onAtpAdvantageError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getAtpAdvantageData " + err);
        }
    };

     /** binding ATP Advantages body data **/
    this.bindATPAdvantagesResponse = function (response) {
        try {
            $("#atp-advantage-content").append(response.Content);
            if (response.Query !== null) {
                var scriptQuery = '<script language="JavaScript">';
                scriptQuery = scriptQuery + response.Query;
                scriptQuery = scriptQuery + '</script>';
                $("#atp-advantage-content").append(scriptQuery);
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : bindATPAdvantagesResponse " + err);
        }
    };

    /** Creating request Parameters **/
    this.getATPAdvantageParameters = function () {
        try {
            var sessionData = applicationDataObj.getSessionResponse(),
                data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "BenefitsServiceProvider";
            data.ServiceMethod = "GetATPAdvantage";
            data.Language = constants.englishLanguage;
            data.parametersArray = ["02C1359E-D474-4806-8309-A008E62C71DB"];
            userSession.PlayerId = sessionData.playerId;
            userSession.Userid = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.TOKEN = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getATPAdvantageParameters " + err);
        }
    };

    /*Ajax - Success Call back*/
    this.onAtpAdvantageSuccess = function (data) {
        try {
            var benefitsAdvantagesObj = new BenefitsAdvantagesClass();
            benefitsAdvantagesObj.bindATPAdvantagesResponse(data);
            endLoading();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnAtpAdvantageSuccess " + err);
        }
    };

    /*Ajax - Error Call back*/
    this.onAtpAdvantageError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnAtpAdvantageError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnAtpAdvantageError " + err);
        }
    };
};

/** ATP Advantages **/

var atpadvantage = function () {
    try {
        if (isApp) {
            window.ga.trackView('Benefits ATP Advantage');
        }
        var benefitsAdvantagesObj = new BenefitsAdvantagesClass(),
            role = "",
            lowerConvertedRole;
        role = applicationDataObj.getSessionResponse().roles[0];
        lowerConvertedRole = role.toLowerCase();
        startLoading();
        headerMain();
        subHeaderBenefitsHide();
        if (lowerConvertedRole.indexOf("atp coach/atp agent") === 0 || lowerConvertedRole.indexOf("atp agent") === 0) {
            navigationArrowMenuAgent();
        } else {
            navigationArrowMenu();
        }
        benefitsAdvantagesObj.getAtpAdvantageData();
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "Error : atpadvantage " + err);
    }
};