/**
Clas Name       : CarousalClass, GetThisWeekClass
Description     : Methods for binding carousal in Home Page, Get This Week items in Home Page
Ownership Info  : This software is the confidential and proprietary information of ATP and may not be used, reproduced, modified, distributed,
                    publicly displayed or otherwise disclosed without the express written consent of ATP. 
*/

/*jslint browser: true*/
/*global $, jQuery,loggerObj,constants,applicationDataObj,Apiservicecalls,OnCarousalSuccess,OnCarousalError,getNewsArticleItemRequestParameters,getNewsArticleItemSucess,getNewsArticleItemFailure,endLoading,timoutErrorStatus,logout,GetThisWeekClass*/

var CarousalClass = function () {
    //Function for creating request for carousal  data
    this.getCarousalParameters = function (sessionData) {
        try {
            var data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "CarouselProvider";
            data.ServiceMethod = "GetCarousel";
            data.Language = constants.englishLanguage;
            data.parametersArray =  ["21974CDF-F4AC-4900-9A7A-F602BC12D850"];
            userSession.PlayerId = sessionData.playerId;
            userSession.Userid = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.TOKEN  = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "In getCarousalParameters : " + err);
        }
    };
    
    this.carousalData = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                sessionData = applicationDataObj.getSessionResponse(),
                inputData = this.getCarousalParameters(sessionData);
	        apiservicecallsObj.postData(constants.ajaxUrl, inputData, OnCarousalSuccess, OnCarousalError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "In CarousalData : " + err);
        }
    };
};

//Initialize Carousal
var initializeCarousal = function () {
    $('.homepage-carousel').slick({
        autoplay: true,
        autoplaySpeed: 4000,
        dots: true,
        infinite: true,
        speed: 1000,
        slide: 'div',
        cssEase: 'linear'
    });
};

//Bind Carousal
var initializeCarousalClick = function () {
	$(".carousalclassanchor").click(function (event) {
		try {
            var newsId = $(this).attr("data-articled"),
                apiservicecallsObj = new Apiservicecalls(),
                url = constants.ajaxUrl,
                inputData = getNewsArticleItemRequestParameters(newsId);
			apiservicecallsObj.postData(url,  inputData,  getNewsArticleItemSucess,  getNewsArticleItemFailure);
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError,  "Error : initializeCarousalClick " +  err);
		}
	});
};

var getNewsArticleItemRequestParameters = function (newsId) {
    try {
        var sessionData = applicationDataObj.getSessionResponse(),
            data = {},
            userSession = {},
            inputData;
        data.Userid = sessionData.userId;
        data.ServiceProvider = "NewsServiceProvider";
        data.ServiceMethod = "GetNewsArticleItem";
        data.Language = constants.englishLanguage;
        data.parametersArray =  [newsId];
        userSession.PlayerId = sessionData.playerId;
        userSession.Userid = sessionData.userId;
        userSession.FirstName = sessionData.firstName;
        userSession.LastName = sessionData.lastName;
        userSession.UserName = applicationDataObj.getUsername();
        userSession.Roles = sessionData.roles;
        userSession.TOKEN  = applicationDataObj.getToken();
        data.SessionData = userSession;
        inputData = JSON.stringify(data);
        return inputData;
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError,  "Error : getNewsArticleItemRequestParameters " +  err);
    }
};

var getNewsArticleItemFailure = function (jqXHR, error) {
    endLoading();
    var errMsg;
    if (jqXHR.status && jqXHR.status === 401 && jqXHR.statusText === "Unauthorized") {
        errMsg = "Error : getNewsArticleItemFailure " + jqXHR.statusText;
    } else if (jqXHR.statusText === "timeout" && jqXHR.status === 0) {
        timoutErrorStatus = true;
        errMsg = "Error : getNewsArticleItemFailure " + jqXHR.statusText;
    } else if (jqXHR.status === 0) {
        timoutErrorStatus = true;
        errMsg = "Error : getNewsArticleItemFailure Unexpected Error with status Code 0";
    } else {
        timoutErrorStatus = true;
        errMsg = "Error : loadMwebUrl Unexpected Error";
    }
    loggerObj.logToServer(constants.logSeverityError, errMsg);
    logout();
};

var getNewsArticleItemSucess = function (response) {
    try {
        var newsArchiveObj = {};
        newsArchiveObj.title = response.ArticleTitle;
        newsArchiveObj.text = response.ArticleBodyText;
        if (response.ThumbnailImage) {
            newsArchiveObj.img = response.ThumbnailImage.Src;
        }
        applicationDataObj.setnewsArchiveDetailObj("");
        applicationDataObj.setnewsArchiveDetailObj(newsArchiveObj);
        endLoading();
        window.location.href = "#/News_NewsArchive_Details";
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError,  "Error : getNewsArticleItemSucess " +  err);
    }
};


// Function to bind the carousal  UI
var getCarousal = function (data) {
    try {
        var carousal_data = "",
            k,
            j;
        for (k = 0; k < data.CarouselItems.length; k = k + 1) {
            j = k + 1;
            if (j === data.CarouselItems.length) {
                j = 0;
            }
            carousal_data += '<div class="carousalclass"><img src="' + data.CarouselItems[k].Image.Src + '"><span class="homepage-carousel-descriptn"><a class="carousalclassanchor" data-articled = "' + data.CarouselItems[j].ArticleId + '" data-id = "' + data.CarouselItems[j].Id + '">' + data.CarouselItems[j].CarouselText + '</a></span></div>';
        }
        $(".homepage-carousel").html(carousal_data);
        initializeCarousal();
        initializeCarousalClick();
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "In getCarousal : " + err);
    }
};
//constants.carousalUrl

//Carousal data fetch Success
var OnCarousalSuccess = function (data) {
    try {
        if (data) {
            getCarousal(data);
        }
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "In OnCarousalSuccess : " + err);
    }
};
	
//Carousal data fetch Error
var OnCarousalError = function (jqXHR, error) {
    try {
        endLoading();
        if (jqXHR.statusText === "timeout" && jqXHR.status === 0) {
            timoutErrorStatus = true;
            logout();
        }
        if (jqXHR.status === 0) {
            timoutErrorStatus = true;
            logout();
        }
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "In OnCarousalError : " + err);
    }
};

//Sucess method of api call getthis week 
var OnthisweekSuccess = function (data) {
    try {
        var getThisWeekClass = new GetThisWeekClass();
        if (data) {
            getThisWeekClass.getThisWeek(data);
        }
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "OnthisweekSuccess : " + err);
    }
};

//Error method of api call getthis week 
var OnthisweekError = function (jqXHR, error) {
    try {
        endLoading();
        if (jqXHR.status && jqXHR.status === 401 && jqXHR.statusText === "Unauthorized") {
            logout();
        }
        if (jqXHR.statusText === "timeout" && jqXHR.status === 0) {
            timoutErrorStatus = true;
            logout();
        }
        if (jqXHR.status === 0) {
            timoutErrorStatus = true;
            logout();
        }
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "OnthisweekError : " + err);
    }
};


var GetThisWeekClass = function () {
    //Function to get thisweek  data
    this.thisweek = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                sessionData = applicationDataObj.getSessionResponse(),
                inputData = this.getThisWeekParameters(sessionData);
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, OnthisweekSuccess, OnthisweekError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "In GetThisWeekClass thisweek : " + err);
        }
    };
    
    //Function for creating request for thisweek  data
    this.getThisWeekParameters = function (sessionData) {
        try {
            var data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "HomeServiceProvider";
            data.ServiceMethod = "GetThisWeekItems";
            data.Language = constants.englishLanguage;
            data.parametersArray =  ["D81D8A45-7C48-40B5-B712-6E5AFC1D8158"];
            userSession.PlayerId = sessionData.playerId;
            userSession.Userid = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.TOKEN  = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "In GetThisWeekClass getThisWeekParameters : " + err);
        }
    };
    
    //Function to bind the thisweek  UI
    this.getThisWeek = function (data) {
        try {
            $(".homepage-thisweek-text").append(data.SectionHeading);
            $(".drawdata").append(data.Navigation[0].Destination.Text);
            $(".orderdata").append(data.Navigation[1].Destination.Text);
            if (data.EventName) {
                $("#eventName").show();
                $("#eventName>a").text(data.EventDisplayName);
                if (data.EventLink && data.EventLink.Url) {
                    $("#eventName>a").attr("data-url", data.EventLink.Url);
                }
                $("#eventName>a").attr("data-eventId", data.EventId);
            } else {
                $("#eventName").hide();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "In GetThisWeekClass getThisWeek : " + err);
        }
    };
};