/**
 * This software is the confidential and proprietary information of
 * ATP and may not be used, reproduced, modified, distributed,
 * publicly displayed or otherwise disclosed without the express written
 * consent of ATP. 
 */
/*jslint browser: true*/
/*global $, jQuery,loggerObj,constants,Apiservicecalls,applicationDataObj,startLoading*/

/* Council and Board class */

var CouncilBoardClass = function () {
    /** get Council Board data **/
    this.getCouncilBoardData = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                inputData = this.getPlayerCBRequestParameters();
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnPlayerCBSuccess, this.OnPlayerCBError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getCouncilBoardData " + err);
        }
    };
    
    /** Creating PlayerCBRequest Parameters **/
    this.getPlayerCBRequestParameters = function () {
        try {
            var sessionData = applicationDataObj.getSessionResponse(),
                data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "CouncilBoardServiceProvider";
            data.ServiceMethod = "GetPlayerCB";
            data.Language = constants.englishLanguage;
            data.parametersArray = ["7677670B-9074-45D8-8CBD-F5F8E7ADD240"];
            userSession.PlayerId = sessionData.playerId;
            userSession.Userid = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.TOKEN  = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getPlayerCBRequestParameters " + err);
        }
    };
    
    /** binding PlayerCB body data **/
    this.bindPlayerCB = function (data) {
        try {
            startLoading();
            $("#councilpara").append(data.PlayerCouncilBody);
            $("#councilpara").find('span').removeAttr('style');
            $("#organizationstruct").append(data.Text);
            $("#organizationstruct").attr('data-url', data.PDF.Src);
            $("#organizationstruct").click(function () {
                $("#organizationstruct").css('color', '#00adf9');
            });
            $("#boardrep").append(data.PlayerRepresentatives);
            $("#counciltitle").append(data.PlayerCouncilHeading);
            this.getplayerBoard();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : bindPlayerCB " + err);
        }
    };
    
    /*Ajax - Success Call back*/
    this.OnPlayerCBSuccess = function (data) {
        try {
            var playerCBClassObj = new CouncilBoardClass();
            playerCBClassObj.bindPlayerCB(data);
            endLoading();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnPlayerCBSuccess " + err);
        }
    };
    
    /*Ajax - Error Call back*/
    this.OnPlayerCBError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnPlayerCBError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnPlayerCBError " + err);
        }
    };
    
    /** get player Board data **/
    this.getplayerBoard = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                inputData = this.getPlayerBoardRequestParameters();
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnPlayerBoardSuccess, this.OnPlayerBoardError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getplayerBoard " + err);
        }
    };
    
    /** Creating Player Board Request Parameters **/
    this.getPlayerBoardRequestParameters = function () {
        try {
            var sessionData = applicationDataObj.getSessionResponse(),
                data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "CouncilBoardServiceProvider";
            data.ServiceMethod = "GetPlayerCBInformation";
            data.Language = constants.englishLanguage;
            data.parametersArray = ["7A7B5B56-DCD7-438D-B11E-B4F16A96D750"];
            userSession.PlayerId = sessionData.playerId;
            userSession.Userid = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.TOKEN  = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getPlayerBoardRequestParameters " + err);
        }
    };
    
    /** binding PlayerBoard body data **/
    this.bindPlayerBoard = function (data) {
        try {
            startLoading();
            var boardInfo = data.Children,
                boardChild = boardInfo.length,
                i;
            if (boardChild !== 0) {
                for (i = 0; i < boardChild; i = i + 1) {
                    if (boardInfo[i].PlayerHeadshot === null) {
                        $("#boardplayer").append('<div class="role-innercntnr3 commondivclass margin-top-15 ">' +
                                     '<div class="pull-left plyrimg_profile">' +
                                     '<figure>' +
                                     '<img class="contact-img_team_player2 img-team-background-color" src="images/Photo_Grey.png" alt="playerimage">' +
                                     '</figure></div>' +
                                     '<div class="pull-left teamprofile_detail paddingleft20">' +
                                     '<div class="role-playername paddingb-5" data-toggle="modal" data-target="#container-div2">' + boardInfo[i].PlayerName + '</div>' +
                                     '<div class="player_profile2 paddingb-10">' + boardInfo[i].RankingGroup + '</div>' +
                                     '<div class="player_profile2">' + boardInfo[i].Description + '</div>' +
                                     '<a href= "mailto:' + boardInfo[i].EmailAddress + '"><img src="images/e-mail_no_fill.png"  class="profile-email-mobile" alt="mobile"></a>' +
                                     '</div></div>');
                    } else {
                        headShotImage = boardInfo[i].PlayerHeadshot.Src;
                        var headShotImageSrc = headShotImage;
                        $("#boardplayer").append('<div class="role-innercntnr3 commondivclass margin-top-15 ">' +
                                     '<div class="pull-left plyrimg_profile">' +
                                     '<figure>' +
                                     '<img class="contact-img_team_player2 img-team-background-color" src="' + headShotImageSrc + '" alt="playerimage">' +
                                     '</figure></div>' +
                                     '<div class="pull-left teamprofile_detail paddingleft20">' +
                                     '<div class="role-playername paddingb-5" data-toggle="modal" data-target="#container-div2">' + boardInfo[i].PlayerName + '</div>' +
                                     '<div class="player_profile2 paddingb-10">' + boardInfo[i].RankingGroup + '</div>' +
                                     '<div class="player_profile2">' + boardInfo[i].Description + '</div>' +
                                     '<a href= "mailto:' + boardInfo[i].EmailAddress + '"><img src="images/e-mail_no_fill.png"  class="profile-email-mobile" alt="mobile"></a>' +
                                     '</div></div>');
                    }
                }
            }
            this.getcouncilCBInfo();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : bindPlayerBoard " + err);
        }
    };
    
    /*Ajax - Success Call back*/
    this.OnPlayerBoardSuccess = function (data) {
        try {
            var playerBoardClassObj = new CouncilBoardClass();
            playerBoardClassObj.bindPlayerBoard(data);
            endLoading();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnPlayerBoardSuccess " + err);
        }
    };
    
    /*Ajax - Error Call back*/
    this.OnPlayerBoardError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnPlayerBoardError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnPlayerBoardError " + err);
        }
    };
    
    /** get council Board data **/
    this.getcouncilCBInfo = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                inputData = this.getCouncilBoardRequestParameters();
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnCouncilBoardSuccess, this.OnCouncilBoardError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getcouncilCBInfo " + err);
        }
    };
    
    /** Creating Council Board Request Parameters **/
    this.getCouncilBoardRequestParameters = function () {
        try {
            var sessionData = applicationDataObj.getSessionResponse(),
                data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "CouncilBoardServiceProvider";
            data.ServiceMethod = "GetPlayerCBInformation";
            data.Language = constants.englishLanguage;
            data.parametersArray = ["62B5E516-F61B-467C-87EF-961049F3D55B"];
            userSession.PlayerId = sessionData.playerId;
            userSession.Userid = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.TOKEN  = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getPlayerBoardRequestParameters " + err);
        }
    };
    
    /** binding councilBoard body data **/
    this.bindCouncilBoard = function (data) {
        try {
            startLoading();
            var councilInfo = data.Children,
                councilChild = councilInfo.length,
                i,
                councilheadShotImage;
            if (councilChild !== 0) {
                for (i = 0; i < councilChild; i = i + 1) {
                    if (councilInfo[i].PlayerHeadshot === null) {
                        $("#councilplayer").append('<div class="role-innercntnr3 commondivclass margin-top-15 ">' +
                                         '<div class="pull-left plyrimg_profile">' +
                                         '<figure>' +
                                         '<img class="contact-img_team_player2 img-team-background-color" src="images/Photo_Grey.png" alt="playerimage">' +
                                         '</figure></div>' +
                                        '<div class="pull-left teamprofile_detail paddingleft20">' +
                                         '<div class="role-playername paddingb-5" data-toggle="modal" data-target="#container-div2">' + councilInfo[i].PlayerName + '</div>' +
                                         '<div class="player_profile2 paddingb-10">' + councilInfo[i].RankingGroup + '</div>' +
                                         '<div class="player_profile2">' + councilInfo[i].Description + '</div>' +
                                         '</div></div>');
                    } else {
                        councilheadShotImage = councilInfo[i].PlayerHeadshot.Src;
                        $("#councilplayer").append('<div class="role-innercntnr3 commondivclass margin-top-15 ">' +
                                         '<div class="pull-left plyrimg_profile">' +
                                         '<figure>' +
                                         '<img class="contact-img_team_player2 img-team-background-color" src="' + councilheadShotImage + '" alt="playerimage">' +
                                         '</figure></div>' +
                                        '<div class="pull-left teamprofile_detail paddingleft20">' +
                                         '<div class="role-playername paddingb-5" data-toggle="modal" data-target="#container-div2">' + councilInfo[i].PlayerName + '</div>' +
                                         '<div class="player_profile2 paddingb-10">' + councilInfo[i].RankingGroup + '</div>' +
                                         '<div class="player_profile2">' + councilInfo[i].Description + '</div>' +
                                         '</div></div>');
                    }
                }
            }
            
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : bindCouncilBoard " + err);
        }
        this.getplayerYears();
    };
    
    /*Ajax - Success Call back*/
    this.OnCouncilBoardSuccess = function (data) {
        try {
            var councilBoardClassObj = new CouncilBoardClass();
            councilBoardClassObj.bindCouncilBoard(data);
            endLoading();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnCouncilBoardSuccess " + err);
        }
    };
    
    /*Ajax - Error Call back*/
    this.OnCouncilBoardError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnCouncilBoardError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnCouncilBoardError " + err);
        }
    };
    
    /** get Years data **/
    this.getplayerYears = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                inputData = this.getYearsRequestParameters();
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnYearsSuccess, this.OnYearsSuccess);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getplayerYears " + err);
        }
    };
    
    /** Creating Years Request Parameters **/
    this.getYearsRequestParameters = function () {
        try {
            var sessionData = applicationDataObj.getSessionResponse(),
                data = {},
                userSession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = "CouncilBoardServiceProvider";
            data.ServiceMethod = "GetYears";
            data.Language = constants.englishLanguage;
            data.parametersArray = ["9A12C3EE-3F94-4E39-AC1C-E65C7A481AE1"];
            userSession.PlayerId = sessionData.playerId;
            userSession.Userid = sessionData.userId;
            userSession.FirstName = sessionData.firstName;
            userSession.LastName = sessionData.lastName;
            userSession.TOKEN  = applicationDataObj.getToken();
            data.SessionData = userSession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getYearsRequestParameters " + err);
        }
    };
    
    /** binding Years body data **/
    this.bindPlayerYears = function (data) {
        try {
            startLoading();
            var councilYears = data.Years,
                yearlen = councilYears.length,
                j,
                k,
                pdfyears,
                pdflen;
            for (j = 0; j < yearlen; j = j + 1) {
                $("#entry_year").append('<option class="dropdowncutoff col-xs-12 col-sm-12" value="' + councilYears[j].Year + '">' + councilYears[j].Year + '</option>');
                $("#councilboardyear").append('<table class="col-xs-12 col-sm-12 table-bordered margin-bottom-30 ' + councilYears[j].Year + '" id="councilboardtable' + j + '">' +
                                 '<tbody class="playercouncilyr" id="councilboardpdf' + j + '">' +
                                 '</tbody></table>');
                pdfyears = councilYears[j].PDFs;
                pdflen = pdfyears.length;
                for (k = 0; k < pdflen; k = k + 1) {
                    $("#councilboardpdf" + j).append('<tr data-year="' + councilYears[j].Year + '" class="Row yrtable">' +
                                                '<td><div class="contactcontentfont">' +
                                                '<img class="pdfwidth" src="images/pdf.svg" alt="pdf" />' +
                                                '<a accesskey="V" data-url ="' + pdfyears[k].PDF.Src + '" onclick = "showCouncilPdf(this);" class="tourdetailtext" download>' + pdfyears[k].Text + '</a>' +
                                                '</div></td></tr>');
                }
            }
            getPDFdetail();
            $(".tourdetailtext").click(function () {
                $(".tourdetailtext").css('color', '#00adf9');
            });
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : bindPlayerYears " + err);
        }
    };
    
    /*Ajax - Success Call back*/
    this.OnYearsSuccess = function (data) {
        try {
            var yearsClassObj = new CouncilBoardClass();
            yearsClassObj.bindPlayerYears(data);
            endLoading();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnYearsSuccess " + err);
        }
    };
    
    /*Ajax - Error Call back*/
    this.OnYearsError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnYearsError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnYearsError " + err);
        }
    };
};

/* Council and Board */

var councilBoard = function () {
    try {
        if (isApp) {
            window.ga.trackView('Contact CouncilBoard');
        }
        var councilBoardObj = new CouncilBoardClass();
        startLoading();
        setTimeout(function () {
            headerMain();
            subHeaderContactHide();
            subHeader();
            subHeaderEllipsis();
            councilBoardObj.getCouncilBoardData();
        }, 500);
        
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "Error : councilBoard " + err);
    }
};


/*Opening pdf*/
var showCouncilPdf = function (event) {
	try {
		var url = $(event).attr("data-url");
	    if (url && url !== "null" && url !== "undefined") {
            window.open(url, "_system");
	    }
	} catch (err) {
		loggerObj.logToServer(constants.logSeverityError, "Error : showCouncilPdf " + err);
	}
};

function getPDFdetail() {
	var dropLen = $("select#entry_year option").length,
        l,
        selectedDropValue;
	for (l = 0; l < dropLen; l = l + 1) {
		selectedDropValue = $('select#entry_year option:selected').val();
		if ($("#councilboardtable" + l).hasClass(selectedDropValue)) {
			$("#councilboardtable" + l).show();
		} else {
            $("#councilboardtable" + l).hide();
        }
	}
}
