/**
 * This software is the confidential and proprietary information of
 * ATP and may not be used, reproduced, modified, distributed,
 * publicly displayed or otherwise disclosed without the express written
 * consent of ATP. 
 */

/* Notification Settings class */

var NotificationSettingsClass = function () {
 
    /** get Notification Settings data **/
    this.getNotificationSettingsData = function () {
        try {
            var apiservicecallsObj = new Apiservicecalls(),
                inputData = this.getNotificationSettingsParameters("NotificationServiceProvider", "GetNotificationCategories", ["a7572221-244b-4689-b6d3-2e074838eeec"]);
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnSettingsSuccess, this.OnNotificationError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getNotificationSettingsData " + err);
        }
    };
    
    /** Creating request Parameters **/
    this.getNotificationSettingsParameters = function (ServiceProvider, ServiceMethod, parametersArray) {
        try {
            var sessionData = applicationDataObj.getSessionResponse(),
                data = {},
                notifySession = {};
            data.Userid = sessionData.userId;
            data.ServiceProvider = ServiceProvider;
            data.ServiceMethod = ServiceMethod;
            data.Language = constants.englishLanguage;
            data.parametersArray =  parametersArray;
            notifySession.PlayerId = sessionData.playerId;
            notifySession.UserId = sessionData.userId;
            notifySession.FirstName = sessionData.firstName;
            notifySession.LastName = sessionData.lastName;
            notifySession.Roles = sessionData.roles;
            notifySession.UserName = applicationDataObj.getUsername();
            notifySession.EmailId = sessionData.emailId;
            notifySession.Address1 = sessionData.address1;
            notifySession.City = sessionData.city;
            notifySession.Country = sessionData.country;
            notifySession.TOKEN  = applicationDataObj.getToken();
            if ((applicationDataObj.getUserType() !== "Player")) {
                notifySession.PlayerId = "";
                if (sessionData.ManagementAgency) {
                    notifySession.ManagementAgency = sessionData.ManagementAgency;
                }
                if (sessionData.registeredDate) {
                    notifySession.JoinedDate = sessionData.registeredDate;
                }
                if (constants.onBehalfPlayerId) {
                    notifySession.OnBehalfPlayerId = constants.onBehalfPlayerId;
                }
            }
            data.SessionData = notifySession;
            data = JSON.stringify(data);
            return data;
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : getNotificationSettingsParameters " + err);
        }
    };
    
  
    
   
    
    /** binding Notification Settings body data **/
    this.bindNotificationSettings = function (data) {
        try {
            bodyText = data.Bodytext;
            myProfiletext = data.MyProfiletext;
            notificationReturnText = data.NotificationReturnText;
            onSiteText = data.OnSiteText;
            onSiteText1 = onSiteText.toLowerCase();
            atpServicesText = data.ATPServicesText;
            atpServicesText1 = atpServicesText.toLowerCase();
            mandatoryUpdatesText = data.MandatoryUpdatesText;
            mandatoryUpdatesText1 = mandatoryUpdatesText.toLowerCase();
            prizeMoneyText = data.PrizeMoneyText;
            prizeMoneyText1 = prizeMoneyText.toLowerCase();
            entriesText = data.EntriesText;
            entriesText1 = entriesText.toLowerCase();
            allNotifications = data.AllNotifications;
            notifications = allNotifications.length;
            toggleSettings = data.NotificationSettings;
            toggleOnOffSettings = toggleSettings.length;
            $(".notificationsetting-profile-heading").append('<div class="notificationsetting-profile-text ">' + myProfiletext + '</div>');
            $(".notificationsetting-heading").append('<a id = "notificationId" class="returnnotify"><div class="notificationsetting-back-arrow pull-left"></div><div class="notificationsetting-back-text pull-left">' + notificationReturnText + '</div><div class="clearfix"></div></a>');
            $(".notificationsetting-content-text").append(bodyText);
            $(".notificationsetting-onsite").append('<div class="notificationsetting-onsite-heading notificationsetting-subheading">' + onSiteText + '</div>');
            $(".notificationsetting-entries").append('<div class="notificationsetting-entries-heading notificationsetting-subheading">' + entriesText + '</div>');
            $(".notificationsetting-prizemoney").append('<div class="notificationsetting-prize-heading notificationsetting-subheading">' + prizeMoneyText + '</div>');
            $(".notificationsetting-atp-service").append('<div class="notificationsetting-atp-heading notificationsetting-subheading">' + atpServicesText + '</div>');
            $(".notificationsetting-mandatory").append('<div class="notificationsetting-mandatory-heading notificationsetting-subheading">' + mandatoryUpdatesText + '</div>');
            for (i = 0; i < notifications; i++) {
                category = allNotifications[i].Category.toLowerCase();
                notificationId = allNotifications[i].NotificationId;
                if (category === onSiteText1 && data.ShowOnSiteSection === true) {
                    $(".notificationsetting-onsite").addClass("show");
                    notification = allNotifications[i].Notification;
                    $(".notificationsetting-onsite").append('<div class="notificationsetting-line"><div class="notificationsetting-line-text pull-left">' + notification + '</div><div class="notificationsetting-toggle-btn pull-left pad-rgt"><span class="notificationsetting-toggle-function" id="' + allNotifications[i].NotificationId + '"><label class="switch"><input type="checkbox" checked="" id="check' + i + '"/><div class="slider round" id="notifysetting_checkbox_' + i + '"></div></label></span></div><div class="clearfix"></div></div>');
                    for (j = 0; j < toggleOnOffSettings; j++) {
                        if ((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && ($("#check" + i).attr("checked", true))) {
                            $("#check" + i).attr("checked", false);
                        } else if ((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && ($("#check" + i).attr("checked", false))) {
                            $("#check"  + i).attr("checked", true);
                        }
                    }
                } 
                if (category === entriesText1 && data.ShowEntriesSection === true) {
                    notification = allNotifications[i].Notification;
                    $(".notificationsetting-entries").addClass("show");
                    $(".notificationsetting-entries").append('<div class="notificationsetting-line"><div class="notificationsetting-line-text pull-left">' + notification + '</div><div class="notificationsetting-toggle-btn pull-left pad-rgt"><span class="notificationsetting-toggle-function" id="' + allNotifications[i].NotificationId + '"><label class="switch"><input type="checkbox" checked="" id="check' + i + '"/><div class="slider round" id="notifysetting_checkbox_' + i + '"></div></label></span></div><div class="clearfix"></div></div>');
                    for (j = 0; j < toggleOnOffSettings; j++) {
                        if ((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && 
                            ($("#check" + i).attr("checked", true))) {
                            $("#check" + i).attr("checked", false);
                        } else if ((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && 
                            ($("#check" + i).attr("checked", false))) {
                            $("#check" + i).attr("checked", true);
                        }
                    }
                } 
                if (category === prizeMoneyText1 && data.ShowPrizeMoneySection === true) {
                    $(".notificationsetting-prizemoney").addClass("show");
                    notification = allNotifications[i].Notification;
                    $(".notificationsetting-prizemoney").append('<div class="notificationsetting-line"><div class="notificationsetting-line-text pull-left">' + notification + '</div><div class="notificationsetting-toggle-btn pull-left pad-rgt"><span class="notificationsetting-toggle-function" id="' + allNotifications[i].NotificationId + '"><label class="switch"><input type="checkbox" checked="false" id="check' + i + '"/><div class="slider round" id="notifysetting_checkbox_' + i + '"></div></label></span></div><div class="clearfix"></div></div>');
                    for (j = 0; j < toggleOnOffSettings; j++) {
                        if ((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && 
                            ($("#check" + i).attr("checked", true))) {
                            $("#check" + i).attr("checked", false);
                        } else if ((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && 
                            ($("#check" + i).attr("checked", false))) {
                            $("#check" + i).attr("checked", true);
                        }
                    }
                } 
                if (category === atpServicesText1 && data.ShowATPServicesSection === true) {
                    $(".notificationsetting-atp-service").addClass("show");
                    notification = allNotifications[i].Notification;
                    $(".notificationsetting-atp-service").append('<div class="notificationsetting-line"><div class="notificationsetting-line-text pull-left">' + notification + '</div><div class="notificationsetting-toggle-btn pull-left pad-rgt"><span class="notificationsetting-toggle-function" id="' + allNotifications[i].NotificationId + '"><label class="switch"><input type="checkbox" checked="false" id="check' + i + '"/><div class="slider round" id="notifysetting_checkbox_' + i + '"></div></label></span></div><div class="clearfix"></div></div>');
                    for (j = 0; j < toggleOnOffSettings; j++){
                        if((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && 
                            ($("#check" + i).attr("checked", true))) {
                            $("#check" + i).attr("checked", false);
                        } else if((toggleSettings[j].NotificationId === allNotifications[i].NotificationId) && 
                            ($("#check" + i).attr("checked", false))) {
                            $("#check"+i).attr("checked",true);
                        }
                    }
                } 
                if(category.toLowerCase() === mandatoryUpdatesText.toLowerCase() && data.ShowMandatoryUpdatesSection === true) {
                    $(".notificationsetting-mandatory").addClass("show");
                    notification = allNotifications[i].Notification;
                    $(".notificationsetting-mandatory").append('<div class="notificationsetting-line"><div class="notificationsetting-line-text pull-left">' + notification + '</div></div><div class="clearfix"></div></div>');
                }

            }
         
            bindNotificationClick();
            $(".notificationsetting-toggle-function").change(function(){
                if ($('input', this).attr("checked") == "checked")
                {
                    $('input', this).removeAttr("checked");
                }
                else {
                    $('input', this).attr("checked", "checked");
                }
                var toggleId = this.id;
                var toggleSwitchClassObj = new NotificationSettingsClass();
                toggleSwitchClassObj.toggleSwitch(toggleId);
            });
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : bindNotificationSettings " + err);
        }
        
         var addSwipeTo = function (selector) {
			$(selector).swipe("destroy");
           
			$(selector).swipe({
				//Generic swipe handler for all directions
				swipe: function (event, direction, distance, duration, fingerCount) {
                     var checkboxId = $(selector).prev().attr("id"); 
                     var checkbox = '#' + checkboxId;
					if (direction === "right") {
						
				     $(checkbox).prop('checked', true);
					
                       
					} else if (direction === 'left') {
						$(checkbox).prop('checked', false);
					} else {
						
							if ($(checkbox).is(':checked')) {
								$(checkbox).prop('checked', false);
							} else {
								$(checkbox).prop('checked', true);
							}
					}
                //var toggleId = this.id;
                var toggleSwitchClassObj = new NotificationSettingsClass();
                toggleSwitchClassObj.toggleSwitch(checkbox);

				},
				//Default is 75px, set to 0 for demo so any distance triggers swipe
				threshold: 0
			});
		};

        
         $(".slider").each(function(){
            var sliderId = $(this).attr('id');
            var slider= '#'+sliderId;
            addSwipeTo(slider);
         });
        
        
    };
    
     /*Ajax - Success Call back*/
    this.OnSettingsSuccess = function (data) {
        try {
            var notificationSettingsClassObj = new NotificationSettingsClass();
            notificationSettingsClassObj.bindNotificationSettings(data);
            endLoading();
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnSettingsSuccess " + err);
        }
    };
    
    /*Ajax - Error Call back*/
    this.OnSettingsError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnSettingsError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnSettingsError " + err);
        }
    };
    
    /** get Toggle data **/
    this.toggleSwitch = function (toggleId) {
        try {
            var apiservicecallsObj = new Apiservicecalls();
            toggleArray=[];
            toggleArray.push(toggleId);
            toggleArray.push("a7572221-244b-4689-b6d3-2e074838eeec");
            parametersArray=toggleArray;
            var inputData = this.getNotificationSettingsParameters("NotificationServiceProvider", "notificationsDataSubscription", parametersArray);
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnToggleSuccess, this.OnToggleError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : toggleSwitch " + err);
        }
    }; 
    
      /** get Toggle data NonPlayer **/
    this.toggleSwitchNonPlayer = function (notificationId,itemId,playerId,checked) {
        try {
            var apiservicecallsObj = new Apiservicecalls();
            toggleArray=[];
            toggleArray.push(notificationId);
            toggleArray.push(itemId);
            toggleArray.push(playerId);
            toggleArray.push(checked);
            parametersArray=toggleArray;
            var inputData = this.getNotificationSettingsParameters("MyProfileServiceProvider", "notificationsDataSubscription", parametersArray);
            apiservicecallsObj.postData(constants.ajaxUrl, inputData, this.OnToggleSuccess, this.OnToggleError);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : toggleSwitch " + err);
        }
    };
    
    
     /*Ajax - Success Call back*/
    this.OnToggleSuccess = function (data) {
        try {
            if(data === true)
            {
                endLoading();
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnToggleSuccess " + err);
        }
    };
    
    /*Ajax - Error Call back*/
    this.OnToggleError = function (jqXHR, error) {
        try {
            endLoading();
            var errorMessage = jqXHR.statusText;
            if (jqXHR.responseJSON && jqXHR.responseJSON.Message) {
                errorMessage = errorMessage + " : " + jqXHR.responseJSON.Message;
            }
            loggerObj.logToServer(constants.logSeverityError, "Error : OnToggleError " + errorMessage);
            if (jqXHR.status && jqXHR.status === constants.errorCode401 &&
                    jqXHR.statusText === constants.unauthorizedError) {
                logout();
            }
        }
        catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "Error : OnToggleError " + err);
        }
    };

};

/* Notification Settings*/


var notificationSettings = function () {
    try {
        if(isApp){
            window.ga.trackView('Nottification Settings');
        }
        var notificationSettingObj = new NotificationSettingsClass();
        startLoading();
        setTimeout(function () {
            headerMain();
            if(constants.onBehalfPlayerId){
                $(".headercontent").hide();
                $(".mngplyhdr-plyrnm").text("");
                $(".mngplyhdr-plyrnm").text(notifyPlayernameObj.playerName);
                $(".manageplyr-header").removeClass("hide");
                $(".manageplyr-header").addClass("show");
                $(".mngingplyr-img").attr('src', constants.headShotImage);
                $(".notificationsetting-profile-text").hide();
            }
             
            notificationSettingObj.getNotificationSettingsData();
            
            if(deviceOS == 'ios' && isApp){
               $('#iosscroll').addClass("scrollcontent");
            }
        }, 500);
        
        
    }
    catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "Error : notificationSettings " + err);
    }
};

var bindNotificationClick = function(){
	$("#notificationId").click(function(){
		if(!constants.onBehalfPlayerId){
			window.location.href="#/Notification";
		}else{
			window.location.href = "#/MyAccount/?onBehalfPlayerId=" + constants.onBehalfPlayerId + "&receiveEmailNotifications=" + notifyPlayernameObj.receiveEmailNotifications+ "&playerName="+notifyPlayernameObj.playerName+"&notfication=yes";
		}
	});
};



$(".notificationsetting-back-text").click(function(){
    if(!constants.onBehalfPlayerId){
        window.location.href="#/Notification";
    }else{
        window.location.href = "#/MyAccount/?onBehalfPlayerId=" + constants.onBehalfPlayerId + "&receiveEmailNotifications=" + notifyPlayernameObj.receiveEmailNotifications+ "&playerName="+notifyPlayernameObj.playerName+"&notfication=yes";
    }
});