/**
Clas Name       : PhotoUploadClass
Description     : MyProfile Account Photo Tab
Ownership Info  : This software is the confidential and proprietary information of ATP and may not be used, reproduced, modified, distributed,
                    publicly displayed or otherwise disclosed without the express written consent of ATP. 
*/

var savedImageUri;

//When camera icon in photo tab is clicked below method is called
var cameraClick = function (source) {
	$('#photoUploadModal').modal("show");
};

// Called when a photo is successfully retrieved from camera
var onPhotoDataSuccess = function (imageURI) {
    $('#photoUploadModal').modal("hide");
    var cImage = document.getElementById('cropImage');
    cImage.style.display = 'block';
    cImage.src = "data:image/jpeg;base64," + imageURI;
    $('#photoCropModal').modal("show");
    resizeableImage($('.resize-image'));
};

// Called when a photo is successfully retrieved from gallery
var onPhotoURISuccess = function (imageURI) {
    $('#photoUploadModal').modal("hide");
    var cImage = document.getElementById('cropImage');
    cImage.style.display = 'block';
    cImage.src = "data:image/jpeg;base64," + imageURI;
    $('#photoCropModal').modal("show");
    resizeableImage($('.resize-image'));
};

var onFail = function (message) {
    console.log('Failed because: ' + message);
};

// Take picture using device camera and retrieve image as base64-encoded string
var capturePhoto = function () {
    navigator.camera.getPicture(onPhotoDataSuccess, onFail, {
        quality: 30,
        targetWidth: 320,
        targetHeight: 640,
        destinationType: destinationType.DATA_URL,
        correctOrientation: true,
        allowEdit: false,
        saveToPhotoAlbum: true
    });
};

// Retrieve image file location from specified source
var getPhoto = function (source) {
    navigator.camera.getPicture(onPhotoURISuccess, onFail, {
        quality: 30,
        targetWidth: 320,
        targetHeight: 640,
        destinationType: destinationType.DATA_URL,
        correctOrientation: true,
        allowEdit: false,
        sourceType: source
    });
};

var onClickCropCancel = function () {
	$("#photoCropModal").modal('hide');
};


var dataURLToBlob = function (dataURL) {
    try {
        var BASE64_MARKER = ';base64,',
            parts,
            contentType,
            raw,
            rawLength,
            uInt8Array;
        if (dataURL.indexOf(BASE64_MARKER) === -1) {
            parts = dataURL.split(',');
            contentType = 'image/jpeg';
            raw = decodeURIComponent(parts[1]);
            return new Blob([raw], {type: contentType});
        }

        parts = dataURL.split(BASE64_MARKER);
        contentType = 'image/jpeg';
        raw = window.atob(parts[1]);
        rawLength = raw.length;
        uInt8Array = new Uint8Array(rawLength);

        for (i = 0; i < rawLength; ++i) {
            uInt8Array[i] = raw.charCodeAt(i);
        }
        return new Blob([uInt8Array], {type: contentType});
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "dataURLToBlob method My Profile Photo Tab " + err);
    }
};

$('.img-photo-image').attr('height', '125px');

var OnPhotoUploadSuccess = function (response) {
    try {
        endLoading();
        if (response) {
            $(".photo-para").empty();
            $(".photo-para").append(response.PhotoDetails.Description);
            if (response.UserImage) {
                $('#photoImage').attr('src', response.UserImage);
                $('.photo-image').css('background-image', 'none');
                $('.img-photo-image').attr('height', '125px');
                $('.img-photo-image').attr('width', '125px');
                if (!constants.onBehalfPlayerId) {
                    $('.img-user-icon').attr('src', response.UserImage);
                    applicationDataObj.setProfilePic(response.UserImage);
                    if (applicationDataObj.getNavigationObj() !== undefined) {
                        var obj = applicationDataObj.getNavigationObj();
                        obj.ProfilePictureSrc = response.UserImage;
                        applicationDataObj.setNavigationObj(obj);
                    }
                }
            } else {
                $('#photoImage').attr('src', '');
                $('.photo-image').css('background-image', '');
            }
        }
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "OnPhotoUploadSuccess method My Profile Photo Tab " + err);
    }
};

var OnPhotoUploadError = function (jqXHR, error) {
    try {
        endLoading();
        if (jqXHR.status && jqXHR.status === 401 && jqXHR.statusText === "Unauthorized") {
            logout();
        } else if (jqXHR.status && jqXHR.status === 500) {
            logout();
        }
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "OnPhotoUploadError method My Profile Photo Tab " + err);
    }
};

var getPhotoUploadInputRequestDetais = function () {
    try {
        var sessionData = applicationDataObj.getSessionResponse(),
            data = {},
            userSession = {};
        data.UserId = sessionData.userId;
        data.ServiceProvider = "MyProfileServiceProvider";
        data.ServiceMethod = "GetHeadshot";
        data.Language = constants.englishLanguage;
        data.parametersArray =  ["B40CE5A1-CF70-4913-BA05-3A15B04B3A4D"];
        userSession.PlayerId = sessionData.playerId;
        userSession.UserId = sessionData.userId;
        userSession.FirstName = sessionData.firstName;
        userSession.LastName = sessionData.lastName;
        userSession.UserName = applicationDataObj.getUsername();
        userSession.Roles = sessionData.roles;
        userSession.EmailId = sessionData.emailId;
        userSession.Address1 = sessionData.address1;
        userSession.City = sessionData.city;
        userSession.Country = sessionData.country;
        userSession.TOKEN  = applicationDataObj.getToken();
        if ((applicationDataObj.getUserType() !== "Player")) {
            userSession.PlayerId = "";
            if (sessionData.ManagementAgency) {
                userSession.ManagementAgency = sessionData.ManagementAgency;
            }
            if (sessionData.registeredDate) {
                userSession.JoinedDate = sessionData.registeredDate;
            }
            if (constants.onBehalfPlayerId) {
                userSession.OnBehalfPlayerId = constants.onBehalfPlayerId;
            }
        }
        data.SessionData = userSession;
        data = JSON.stringify(data);
        return data;
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "getPhotoUploadInputRequestDetais method My Profile Photo Tab " + err);
    }
};

var getPhotoUpload = function () {
    try {
        var apiservicecallsObj = new Apiservicecalls(),
            inputData = getPhotoUploadInputRequestDetais();
        apiservicecallsObj.postData(constants.ajaxUrl, inputData, OnPhotoUploadSuccess, OnPhotoUploadError);
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "getPhotoUpload method My Profile Photo Tab " + err);
    }
};



var cancelPhotoUpload = function () {
    try {
        $('.reg13-div').hide();
	    $('#photoImage').removeClass('uriChanged');
	    getPhotoUpload();
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "cancelPhotoUpload method My Profile Photo Tab " + err);
    }
};

var OnPhotoApiSuccess = function (respdata) {
    $("#photoSkip").text('Next..');
    if (!constants.onBehalfPlayerId) {
        applicationDataObj.setProfilePic(savedImageUri);
        $('.img-user-icon').attr('src', applicationDataObj.getProfilePic());
        var obj = applicationDataObj.getNavigationObj();
        obj.ProfilePictureSrc = savedImageUri;
        applicationDataObj.setNavigationObj(obj);
    }
    else {
        $('.mngingplyr-img').attr('src', savedImageUri);
    }

    $('.reg13-div').show();
    $('#noImage').hide();
    $('#successMessage').show();
};

var OnPhotoApiError = function (errorMsg) {
    loggerObj.logToServer(constants.logSeverityError, "Photo Upload failed in Photo Tab " + errorMsg);
};

var savePhotoUpload = function () {
    try {
        var imageURI = $('#photoImage').attr('src'),
            blob,
            apiservicecallsObj,
            sessionData,
            data = new FormData(),
            parameter = [],
            userSession = {};
        savedImageUri = imageURI;
        if (imageURI !== "") {
            blob = dataURLToBlob(imageURI);
            apiservicecallsObj = new Apiservicecalls();
            sessionData = applicationDataObj.getSessionResponse();
            data.append("FileUpload", blob);
            data.append("Token", applicationDataObj.getToken());
            data.append("ServiceProvider", "MyProfileServiceProvider");
            data.append("ServiceMethod", "SaveHeadshot");
            data.append("Language", constants.englishLanguage);
            parameter.push("B40CE5A1-CF70-4913-BA05-3A15B04B3A4D");
            data.append("parametersArray", parameter);
            data.append("PlayerId", sessionData.playerId);
            data.append("UserId", sessionData.userId);
            data.append("FirstName", sessionData.firstName);
            data.append("LastName", sessionData.lastName);
            data.append("UserName", applicationDataObj.getUsername());
            data.append("Roles", sessionData.roles);
            data.append("EmailId", sessionData.emailId);
            data.append("Address1", sessionData.address1);
            data.append("City", sessionData.city);
            data.append("Country", sessionData.country);
            if ((applicationDataObj.getUserType() !== "Player")) {
                data.append("PlayerId", "");
                if (sessionData.ManagementAgency) {
                    data.append("ManagementAgency", sessionData.ManagementAgency);
                }
                if (sessionData.registeredDate) {
                    data.append("JoinedDate", sessionData.registeredDate);
                }
                if (constants.onBehalfPlayerId) {
                    data.append("OnBehalfPlayerId", constants.onBehalfPlayerId);
                }
            }
            $.ajax({
                url: constants.photoUploadUrl,
                data: data,
                headers: {
                    "Access-Control-Allow-Origin": "*",
                    "Access-Control-Allow-Headers": "Origin, X-Requested-With, Content-Type, Accept"
                },
                crossDomain : true,
                type: "POST",
                contentType: false,
                processData: false,
                success: OnPhotoApiSuccess,
                async: true,
                error: OnPhotoApiError
            });
        } else {
            $('.reg13-div').show();
            $('#successMessage').hide();
            $('#noImage').show();
        }
    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, "savePhotoUpload method My Profile Photo Tab " + err);
    }
};