/**
File Name       : refreshToken.js
Description     : Functionalities for refreshing the token in a configured time interval
Ownership Info  : This software is the confidential and proprietary information of ATP and may not be used, reproduced, modified, distributed,
                    publicly displayed or otherwise disclosed without the express written consent of ATP. 
*/

var RefreshTokenClass = function () {
	var apiservicecallsObj = new Apiservicecalls();
	/**
	 * Function for refreshing the token
	 */
	this.refreshToken = function () {
		try{
			var data = {},
			inputData;
			data.RefreshToken =  applicationDataObj.getRefreshToken();	
			inputData = JSON.stringify(data);
			apiservicecallsObj.postData(constants.ajaxTokenUrl, inputData, this.refreshTokenSuccess, this.refreshTokenError);
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, err);
		}
	}
	/**
	 * Success function of refresh token
	 */
	this.refreshTokenSuccess = function (responseData) {
		endLoading();
        startTokenTimer();
		if (responseData && responseData.Token) {
			applicationDataObj.setToken(responseData.Token.access_token);
            applicationDataObj.setRefreshToken(responseData.Token.refresh_token);
            applicationDataObj.setExpires(responseData.Token[".expires"]);
            if ($('#mWebIframe').length) {
                //HybridApp session is refeshed only when mweb pages are loaded.
                refreshHybrid();
            }
            
		}
	};
	/**
	 * Error handling of refresh token
	 */
	this.refreshTokenError = function (jqXHR) {
		try {
			endLoading();
            var errMsg = "";
            if (jqXHR.status && jqXHR.status === 401 && jqXHR.statusText === "Unauthorized") {
                errMsg = "Error : refreshTokenError " + jqXHR.statusText;
            } else if (jqXHR.statusText === "timeout" && jqXHR.status === 0) {
                timoutErrorStatus = true;
                errMsg = "Error : refreshTokenError " + jqXHR.statusText;
            } else if (jqXHR.status === 0) {
                timoutErrorStatus = true;
                errMsg = "Error : refreshTokenError Unexpected Error with status Code 0";
            } else {
                timoutErrorStatus = true;
                errMsg = "Error : refreshTokenError Unexpected Error";
            }
            loggerObj.logToServer(constants.logSeverityError, errMsg);
            logout();
		} catch (err) {
			loggerObj.logToServer(constants.logSeverityError, err);
		}
	};
};


    
//Method for refreshing HybridApp Session if in Mweb pages
var refreshHybrid = function () {
    try {
        var userId = applicationDataObj.getUserId(),
            token = applicationDataObj.getToken(),
            refTok = applicationDataObj.getRefreshToken(),
            appExpires = applicationDataObj.getExpires();

        $.ajax({
                url: constants.hybridAppLogin,
                data: { "userId": userId,  "token": token, "refreshToken": refTok, "expires": appExpires },
                xhrFields: {
                    withCredentials: true
                },
                crossDomain: true,
                type: "POST",
                async: true,
                timeout: 60000,
                success: function (respdata) {
                    endLoading();
                    if(respdata){
                        console.log("Hybrid App session : "+respdata);
                    }    
                },
                error: function (jqXHR,  exception) {
                    endLoading();
                    if (jqXHR.status && jqXHR.status === 401 && jqXHR.statusText === "Unauthorized") {
                    errMsg = "Error : loadMwebUrl "  + jqXHR.statusText;
                    } else if (jqXHR.statusText === "timeout" && jqXHR.status === 0) {
                    timoutErrorStatus = true;
                    errMsg = "Error : loadMwebUrl "  + jqXHR.statusText;
                    } else if (jqXHR.status === 0) {
                    timoutErrorStatus = true;
                    errMsg = "Error : loadMwebUrl Unexpected Error with status Code 0";
                    } else {
                    timoutErrorStatus = true;
                    errMsg = "Error : loadMwebUrl Unexpected Error";
                    }
                    loggerObj.logToServer(constants.logSeverityError, errMsg);
                    logout();
                    }
            });

    } catch (err) {
        loggerObj.logToServer(constants.logSeverityError, err);
    }
};
  
var timeOutTimerValue = 0;
var tokenTimer;
var popupTimer;
var popupTimerFlag = false;
var con;
var timeoutCnfmBx;
    
var startTokenTimer = function() {
    var tokentime = applicationDataObj.getRemainingTimeAfterWarning();
    var warningMsg = applicationDataObj.getSessionWarningMessage();
    var alertMsg = applicationDataObj.getSessionExpiredMessage();
    clearTimeout(popupTimer);
    popupTimer = setTimeout( function () {
        if(!popupTimerFlag) {
            if(!sessionFlag) {
                endLoading();
                con = $.confirm({
                    title: 'Alert !',
                    content: warningMsg,
                    buttons: {
                        Continue: function () {
                            //Confirmed to Extend
                            popupTimerFlag = false;
                            var refreshTokenClass = new RefreshTokenClass();
                            refreshTokenClass.refreshToken();
                        },
                        Logout: function () {
                            //Logout
                            logout();
                        }
                    },
                    onOpen: function () {
                        // after the modal is displayed.
                        warningCon = true;
                    },
                    onClose: function () {
                        // before the modal is hidden.
                        warningCon = false;
                    },
                    onDestroy: function () {
                        // when the modal is removed from DOM
                        clearTimeout(popupTimer);
                        clearTimeout(tokenTimer);
                    }
                });
             } else {
                    if (warningCon) {
                        con.close();
                        clearTimeout(popupTimer);
                    }
                    if (sessionExpCon) {
                        timeoutCnfmBx.close();
                        clearTimeout(tokenTimer);
                    }
                    sessionFlag = false;
                    logout();
            }
        }
        popupTimerFlag = true;
        
    }, timeOutTimerValue - tokentime); 
    tokenTimer = setTimeout( function () {
           setTimeout( function () {
                if(warningCon){
                      con.close();
                }
           }, 300);
        clearTimeout(tokenTimer);   
        timeoutCnfmBx = $.confirm({
            title: 'Alert !',
            content: alertMsg,
            buttons: {
                Ok: function () {
                    //Logout
                    logout();
                }
            },
            onOpen: function () {
                // after the modal is displayed.
                sessionExpCon = true;
                if (warningCon) {
                    con.close();
                    clearTimeout(popupTimer);
                }
            },
            onClose: function () {
                // before the modal is hidden.
                sessionExpCon = false;
            }
        });
    }, timeOutTimerValue);
};

var refreshTokenTimer = function (){
        if(!popupTimerFlag) {
            if (appStatus === "BACK") {
                bgRefresh = bgRefresh + 1;
            }
            if (bgRefresh < 2 ) {
                var refreshTokenClass = new RefreshTokenClass();
                refreshTokenClass.refreshToken();
            } else {
                logout();
            }
        }
};
