/**
Clas Name       : TokenServiceClass
Description     : Token Services
Ownership Info  : This software is the confidential and proprietary information of ATP and may not be used, reproduced, modified, distributed,
                    publicly displayed or otherwise disclosed without the express written consent of ATP. 
*/
var TokenServiceClass = function () {
    var loginServiceClass = new LoginServiceClass();
    var touchIdAndroid = new TouchIdAndroidClass();
    var touchIdiOS = new TouchIdiOSClass();
    var pushNotificationClass = new PushNotificationClass();
    //create Token services
    this.createToken = function (data) {
        try {
            applicationDataObj.setUsername(data.UserName);
            var apiservicecallsObj = new apiservicecalls(),
                url =  constants.ajaxUrl,
                tokenUrl = constants.ajaxTokenUrl;
            data = JSON.stringify(data);
            apiservicecallsObj.postData(tokenUrl, data, this.loginSuccess, this.loginError);
        } catch (err) {
			loggerObj.logToServer(constants.logSeverityError, "createToken method" + err);
		}
    };
    
    //create token service for fingerprint
    this.createTokenfingerprint = function (data) {
        try {
            applicationDataObj.setUsername(data.UserName);
            var apiservicecallsObj = new apiservicecalls(),
                url =  constants.ajaxUrl,
                tokenUrl =  constants.ajaxTokenUrl;
            data = JSON.stringify(data);
            apiservicecallsObj.postData(tokenUrl, data, this.autheticateFingerSuccess, this.autheticateFingerError);
            
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "createTokenfingerprint method" + err);
        }
    };
    
    //Ajax token success for fingerprint
    this.autheticateFingerSuccess = function (tokenResponse) {
        try {
            deepLinkFlag = false;
            if (tokenResponse) {
                applicationDataObj.setTokenResponse(tokenResponse);
                if (tokenResponse.Session) {
                    applicationDataObj.setSessionResponse(tokenResponse.Session);
                    applicationDataObj.setUserId(tokenResponse.Session.userId);
                    if (tokenResponse.Session.roles && tokenResponse.Session.roles.length !== 0) {
                        var userRole = applicationDataObj.getSessionResponse().roles[0];
                        if (userRole.indexOf("Player") !== -1) {
                            applicationDataObj.setUserType("Player");
                        } else {
                            applicationDataObj.setUserType("NonPlayer");
                        }
                    }
                    var sessionResponse = tokenResponse.Session;
                    applicationDataObj.setToken(tokenResponse.Token.access_token);
                    applicationDataObj.setRefreshToken(tokenResponse.Token.refresh_token);
                    applicationDataObj.setRemainingTimeAfterWarning(tokenResponse.remainingTimeAfterWarning*60*1000);
                    applicationDataObj.setSessionExpiredMessage(tokenResponse.session_expired_message);
                    applicationDataObj.setSessionWarningMessage(tokenResponse.session_warning_message);
                    applicationDataObj.setExpires(tokenResponse.Token[".expires"]);
                    timeOutTimerValue = tokenResponse.Token.expires_in * 1000;
                    startTokenTimer();
                    window.localStorage.setItem("clientId", applicationDataObj.getUserId());
                    window.localStorage.setItem("Username", applicationDataObj.getUsername());
                    if (isApp) {
                        pushNotificationClass.registerNotification();
                    }
                    if (device.platform.toLowerCase() === "android") {
                        FingerprintAuth.isAvailable(touchIdAndroid.isAvailableSuccess, touchIdAndroid.isAvailableError);
                    }
                    if (device.platform.toLowerCase() === "ios") {
                        window.plugins.touchid.isAvailable(touchIdiOS.isAvailableSuccess, touchIdiOS.isAvailableError);
                    }
                 }
            }
        } catch(err) {
            loggerObj.logToServer(constants.logSeverityError, "autheticateFingerSuccess method" + err);
        }
    };
    
    //Ajax token error for fingerprint
    this.autheticateFingerError = function (jqXHR) {
        endLoading();
        try {
            var errorMessage = "Service unavailable";
            if (jqXHR.statusText === "timeout" && jqXHR.status === 0) {
                errorMessage = appMsgs.timeoutError;
            } else if (jqXHR.statusText === "error" && jqXHR.status === 0) {
                errorMessage = appMsgs.timeoutError;
            } else {
                if(jqXHR.responseJSON.Message === 'Your account has been locked. Click the "Forgot Password" link below to reset your password.'){
                    errorMessage = 'Your account is locked. Please go back to the login screen and click Forgot Password link to reset your password.';
                } else {
                    errorMessage = jqXHR.responseJSON.Message;
                }
            }
            $("#invalid_user_fingerprint").html(errorMessage);
            $("#invalid_user_faceId").html(errorMessage);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "autheticateFingerError method" + err);
        }
    };
    
    //Ajax token success for login
    this.loginSuccess = function (tokenResponse) {
        try {
            
            deepLinkFlag = false;
            if (tokenResponse) {
                applicationDataObj.setTokenResponse(tokenResponse);
                if (tokenResponse.Session) {
                    applicationDataObj.setSessionResponse(tokenResponse.Session);
                    applicationDataObj.setUserId(tokenResponse.Session.userId);
                    if (tokenResponse.Session.roles && tokenResponse.Session.roles.length !== 0) {
                        var userRole = applicationDataObj.getSessionResponse().roles[0];
                        if (userRole.indexOf("Player") !== -1) {
                            applicationDataObj.setUserType("Player");
                        } else {
                            applicationDataObj.setUserType("NonPlayer");
                        }
                    }
                    applicationDataObj.setToken(tokenResponse.Token.access_token);
                    applicationDataObj.setRefreshToken(tokenResponse.Token.refresh_token);
                    timeOutTimerValue = tokenResponse.Token.expires_in * 1000;
                    applicationDataObj.setRemainingTimeAfterWarning(tokenResponse.remainingTimeAfterWarning*60*1000);
                    applicationDataObj.setSessionExpiredMessage(tokenResponse.session_expired_message);
                    applicationDataObj.setSessionWarningMessage(tokenResponse.session_warning_message);
                    applicationDataObj.setExpires(tokenResponse.Token[".expires"]);
                    startTokenTimer();
                    if (isApp) {
                        if (window.localStorage.getItem("PushNotification") === null) {
                            pushNotificationClass.registerNotification();
                        } else {
                            if (window.localStorage.getItem("UserId") !== applicationDataObj.getUserId()) {
                                pushNotificationClass.registerNotification();
                            }
                        }
                    }
                    loginServiceClass.getLoginDetails();
                }
            }
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "loginSuccess method" + err);
        }
    };

    //Ajax token error for login
    this.loginError = function (jqXHR) {
        endLoading();
        try {
            var errorMessage = "Service unavailable";
            if (jqXHR.statusText === "timeout" && jqXHR.status === 0) {
                errorMessage = appMsgs.timeoutError;
            } else if (jqXHR.statusText === "error" && jqXHR.status === 0) {
                errorMessage = appMsgs.timeoutError;
            } else {
                errorMessage = jqXHR.responseJSON.Message;
            }
            $('.login-logo-container').css('padding-top', '40px');
            $("#invalid_user").html(errorMessage);
        } catch (err) {
            loggerObj.logToServer(constants.logSeverityError, "loginError method" + err);
        }
    };
};